@@ -3,6 +3,7 @@ from waveletai import constants
 import threading
 from waveletai.sessions import Session
 from waveletai.backends.hosted_backend import HostedBackend
+from waveletai.constants import ModelRegisterMode
 
 logging.basicConfig(format='[%(process)d] [%(asctime)s] %(levelname)s [%(filename)s:%(lineno)s] %(message)s',
                     level=logging.INFO)
@@ -59,4 +60,26 @@ def create_dataset(name, zone, path, data_type=constants.DataType.TYPE_FILE.valu
     return _backend.create_dataset(name, zone, path, data_type, desc)
 
 
+def get_dataset(dataset_id):
+    """
+    获取数据集对象
+    :param dataset_id:数据集ID
+    :return:
+    """
+    global _backend
+    return _backend.get_dataset(dataset_id)
 
+
+def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
+    global _backend
+    return _backend.register_model_version(model_id, desc, artifacts, mode)
+
+
+def get_model(model_id):
+    """
+    获取模型对象
+    :param model_id:模型ID
+    :return:
+    """
+    global _backend
+    return _backend.get_model(model_id)
