@@ -34,6 +34,10 @@ class Backend(object):
     def upload_dataset(self, dataset_id, path):
         pass
 
+    @abstractmethod
+    def get_dataset(self, dataset_id):
+        pass
+
     @abstractmethod
     def download_dataset_artifact(self, dataset_id, path, destination):
         pass
@@ -47,7 +51,7 @@ class Backend(object):
         pass
 
     @abstractmethod
-    def register_model(self, model_id, name, mode, art_id):
+    def register_model_version(self, model_id, desc, artifacts, mode):
         pass
 
     @abstractmethod
