@@ -6,7 +6,7 @@
 @license : (C) Copyright 2019-2022, Visionet(Tianjin)Information Technology Co.,Ltd.
 @Site    : plus.xiaobodata.com
 @File    : env.py
-@Desc    : 
+@Desc    : 废弃，改用envs
 """
 from waveletai.entities.mqtt_repo import MqttRepo
 from waveletai.entities.mqtt_topic import MqttTopic
